@@ -320,7 +320,7 @@ def get_job(api, job_id):
     """
     return api.get('jobs/%s' % job_id)
 
-def get_jobs(api, skip=None, limit=None):
+def get_jobs(api, skip=None, limit=None, search=None, job_type=JOB_TYPE_PIG):
     """
     Get multiple jobs from the API.
 
@@ -333,13 +333,30 @@ def get_jobs(api, skip=None, limit=None):
     :type limit: integer
     :param limit: Total number of jobs to return at once.
 
+    :type search: dict
+    :param search: enables filtering on following keys
+                    'luigiscript_name',
+                    'pigscript_name',
+                    'sparkclass_name',
+                    'notes',
+                    'pig_status',
+                    'luigi_status',
+                    'spark_status',
+                    'show_pig',
+                    'show_spark',
+                    'show_luigi'
+                    Those values are the only valid keys for the search dict
+
+    :type job_type: str
+    :param job_type: 'pig', 'luigi', 'spark' or 'all'
+
     :raises: requests.exception.HTTPError: if a 40x or 50x error occurs
 
     :rtype: list:
     :returns: list of dict of job details
     """
     return api.get('jobs',
-                   params={'skip': skip, 'limit': limit})
+                   params={'skip': skip, 'limit': limit, 'job_type': job_type, 'search': search})
 
 def block_until_job_complete(api, job_id, poll_frequency_sec=5.0):
     """
